@@ -48,13 +48,10 @@
 #include <sys/time.h>
 #include <netinet/in.h>
 #include <sys/socket.h>
-#include <zaptel/zaptel.h>
-#ifndef SOLARIS
-#include <zap.h>
-#endif
 #include <pthread.h>
 #include <sys/select.h>
 #include "libpri.h"
+#include "pri_q921.h"
 #include "pri_q931.h"
 
 #ifndef AF_LOCAL
@@ -66,7 +63,7 @@
 #define PRI_DEF_NODETYPE	PRI_CPE
 #define PRI_DEF_SWITCHTYPE	PRI_SWITCH_NI2
 
-static struct pri *first, *cur;
+static struct pri *first;
 
 static pthread_mutex_t lock = PTHREAD_MUTEX_INITIALIZER;
 
@@ -159,9 +156,9 @@ static void testmsg(struct pri *pri, char *s)
 			*c = '\0';
 			c++;
 		}
-		if (keeplast)
+		if (keeplast || !pri)
 			printf("%s", s);
-		else if (cur == first)
+		else if (pri == first)
 			printf("-1 %s", s);
 		else
 			printf("-2 %s", s);
@@ -185,9 +182,9 @@ static void testerr(struct pri *pri, char *s)
 			*c = '\0';
 			c++;
 		}
-		if (keeplast)
+		if (keeplast || !pri)
 			printf("%s", s);
-		else if (cur == first)
+		else if (pri == first)
 			printf("=1 %s", s);
 		else
 			printf("=2 %s", s);
@@ -207,7 +204,7 @@ static void *dchan(void *data)
 	/* Joint D-channel */
 	struct pri *pri = data;
 	struct timeval *next, tv;
-	pri_event *e;
+	pri_event *e = NULL;
 	fd_set fds;
 	int res;
 	for(;;) {
@@ -228,7 +225,6 @@ static void *dchan(void *data)
 		FD_SET(pri_fd(pri), &fds);
 		res = select(pri_fd(pri) + 1, &fds, NULL, NULL, next ? &tv : NULL);
 		pthread_mutex_lock(&lock);
-		cur = pri;
 		if (res < 0) {
 			perror("select");
 		} else if (!res) {
@@ -238,9 +234,9 @@ static void *dchan(void *data)
 		}
 		if (e) {
 			if (first == pri) {
-				event1(e->gen.pri, e);
+				event1(pri, e);
 			} else {
-				event2(e->gen.pri, e);
+				event2(pri, e);
 			}
 		}
 		pthread_mutex_unlock(&lock);
